@@ -1,6 +1,3 @@
-#$Header: /home/jesse/DBIx-SearchBuilder/history/SearchBuilder/Handle/Pg.pm,v 1.8 2001/07/27 05:23:29 jesse Exp $
-# Copyright 1999-2001 Jesse Vincent <jesse@fsck.com>
-
 package DBIx::SearchBuilder::Handle::Pg;
 
 use strict;
@@ -19,7 +16,7 @@ use Want qw(howmany);
 
 =head1 DESCRIPTION
 
-This module provides a subclass of DBIx::SearchBuilder::Handle that 
+This module provides a subclass of DBIx::SearchBuilder::Handle that
 compensates for some of the idiosyncrasies of Postgres.
 
 =head1 METHODS
@@ -34,15 +31,15 @@ Forces the timezone to GMT
 it returns a database handle.
 
 =cut
-  
+
 sub Connect {
     my $self = shift;
-    
+
     my $rv = $self->SUPER::Connect(@_);
     $self->SimpleQuery("SET TIME ZONE 'GMT'");
     $self->SimpleQuery("SET DATESTYLE TO 'ISO'");
     $self->AutoCommit(1);
-    return ($rv); 
+    return ($rv);
 }
 
 =head2 BuildDSN
@@ -136,14 +133,14 @@ sub IdSequenceName {
         }
 
     }
-            my $ret = Class::ReturnValue->new();
-            $ret->as_error(
-                errno   => '-1',
-                message => "Found no sequence for $table",
-                do_backtrace => undef
-            );
-            return ( $ret->return_value );
 
+    my $ret = Class::ReturnValue->new();
+    $ret->as_error(
+        errno   => '-1',
+        message => "Found no sequence for $table",
+        do_backtrace => undef
+    );
+    return ( $ret->return_value );
 }
 
 
@@ -172,19 +169,26 @@ sub ApplyLimits {
     my $statementref = shift;
     my $per_page = shift;
     my $first = shift;
+    my $sb = shift;
 
     my $limit_clause = '';
 
     if ( $per_page) {
         $limit_clause = " LIMIT ";
+
+        if ( $sb->{_bind_values} ) {
+            push @{ $sb->{_bind_values} }, $per_page, $first || ();
+            $first    = '?' if $first;
+            $per_page = '?';
+        }
+
         $limit_clause .= $per_page;
-        if ( $first && $first != 0 ) {
+        if ( $first ) {
             $limit_clause .= " OFFSET $first";
         }
     }
 
-   $$statementref .= $limit_clause; 
-
+    $$statementref .= $limit_clause;
 }
 
 
@@ -205,7 +209,7 @@ sub _MakeClauseCaseInsensitive {
 
     # we don't need to downcase numeric values and dates
     if ($value =~ /^$DBIx::SearchBuilder::Handle::RE_CASE_INSENSITIVE_CHARS+$/o) {
-        	return ( $field, $operator, $value);
+        return ( $field, $operator, $value);
     }
 
     if ( $operator =~ /LIKE/i ) {
@@ -213,16 +217,15 @@ sub _MakeClauseCaseInsensitive {
         return ( $field, $operator, $value );
     }
     elsif ( $operator =~ /=/ ) {
-	if (howmany() >= 4) {
-        	return ( "LOWER($field)", $operator, $value, "LOWER(?)"); 
-	} 
-	# RT 3.0.x and earlier  don't know how to cope with a "LOWER" function 
-	# on the value. they only expect field, operator, value.
-	# 
-	else {
-		return ( "LOWER($field)", $operator, lc($value));
-
-	}
+        if (howmany() >= 4) {
+            return ( "LOWER($field)", $operator, $value, "LOWER(?)");
+        }
+        # RT 3.0.x and earlier  don't know how to cope with a "LOWER" function
+        # on the value. they only expect field, operator, value.
+        #
+        else {
+            return ( "LOWER($field)", $operator, lc($value));
+        }
     }
     else {
         $self->SUPER::_MakeClauseCaseInsensitive( $field, $operator, $value );
@@ -361,6 +364,10 @@ sub HasSupportForNullsOrder {
 
 __END__
 
+=head1 AUTHOR
+
+Jesse Vincent, jesse@fsck.com
+
 =head1 SEE ALSO
 
 DBIx::SearchBuilder, DBIx::SearchBuilder::Handle
